\name{ROCt632}
\alias{ROCt632}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Estimation of true prognostic capacity of microarray data using the coss-validation, the 0.632 and the 0.632+ estimators of time-dependent ROC curves
}
\description{
This function performs estimations of time-dependent ROC curves according to different bootstrap-based approaches.
}
\usage{
ROCt632(times, failures, features, N.boot,
 precision, prop, pro.time)
}
\arguments{
  \item{times}{A numeric vector with the follow up times.}
  \item{failures}{A numeric vector with the event indicators (0=right censored, 1=event).}
  \item{features}{A matrix with the observed features. The number of raw is the number of individuals (length of the arguments \code{times} and \code{failures}).}
  \item{N.boot}{Number of bootstrap iterations.}
  \item{precision}{The quantiles of the predictor used for computing each point of the time dependent ROC curve.}
  \item{prop}{This is the proportion of the nearest neighbors used in the Akritas estimator. The estimation will be based on 2*lambda (1 lambda on the left and 1 lambda on the right) of the total sample size.}
  \item{pro.time}{The value(s) of prognostic time represent(s) the maximum delay(s) for which the capacity of the variable is evaluated. The same unit than the one used in the argument \code{times}.}
}
\details{
This function computes time-dependent ROC curve with right-censoring data based on the 0.632+ estimator. The Akritas approach (nearest neighbor's estimation) is used for ensuring monotone and increasing ROC curve. The theory was defined by Heagerty, Lumley and Pepe (Biometrics, 2000).
}
\value{
The function returns a data frame. The raw(s) represent(s) the value(s) of the prognostic time. \code{train} is the mean of the areas obtained by using the individuals included in the bootstrap samples (training). \code{valid} is the mean of the areas obtained by using the individuals not included in the bootstrap samples (cross-validation). \code{s632} is the mean of the areas obtained by using the simple 0.632 estimator. \code{p632} is the mean of the areas obtained by using the 0.632+ estimator. 
}
\references{
R. Danger and Y. Foucher. Time dependent ROC curves for the estimation of true prognostic capacity of microarray data. 2011. Submited.}
\author{
Y. Foucher <Yohann.Foucher@univ-nantes.fr>
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{

# import and attach the data example

data(DLBCLpatients)
data(DLBCLgenes)

ROCt632(times=DLBCLpatients$t, failures=DLBCLpatients$f,
 features=DLBCLgenes, N.boot=2,
 precision=seq(0.01, 0.99, by=0.02),
 prop=0.02, pro.time=5)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ 0.632 }
\keyword{ bootstrap }
\keyword{ Time-dependent ROC curve }
